@@ -86,7 +86,7 @@ def populate_initial_data(dm: Dimensigon):
         gates = dm.config.http_conf.get('binds', None)
 
         SchemaChanges.set_initial(session)
-        Server.set_initial(session, gates)
+        dm.server_id = Server.set_initial(session, gates)
 
         Locker.set_initial(session)
         ActionTemplate.set_initial(session)
@@ -140,6 +140,9 @@ def _add_columns(engine, table_name, columns_def):
                     table_name,
                 )
 
+def _rename_table(engine, old_table_name, new_table_name):
+    with engine.connect() as connection:
+        connection.execute(f"ALTER TABLE {old_table_name} RENAME TO {new_table_name}")
 
 def _rename_columns(engine, table_name, column_renames: t.List[t.Tuple[str, str]]):
     temp_table_name = table_name + '_temp'
@@ -371,10 +374,9 @@ def _apply_update(engine, new_version, old_version):
                                            "max_senders": {"type": "integer"},
                                            },
                                  "required": ["software_id", "server_id"],
-                                 "output": {"file": {"type": "string",
-                                                     "description": "absolute path file name"}}
+                                 "output": ["file"]
                                  })
-            post_process = 'if cp.success:\n  json_data=json.loads(cp.stdout)\n  vc.set("file", json_data.get("file"))'
+            post_process = 'import json\nif cp.success:\n  json_data=json.loads(cp.stdout)\n  vc.set("file", json_data.get("file"))'
             code = '{"method": "post",' \
                    '"view":"api_1_0.send",' \
                    '"json": {"software_id": "{{input[\'software_id\']}}", ' \
@@ -444,4 +446,11 @@ def _apply_update(engine, new_version, old_version):
 
             _LOGGER.warning("After this database release, attribute 'parameters' from Step and ActionTemplate are "
                             "deprecated. You need to recreate all user actions and orchestrations using the schema "
-                            "attribute. See documentation for more information.")
\ No newline at end of file
+                            "attribute. See documentation for more information.")
+    elif new_version == 7:
+        _rename_table(engine, 'D_software_server', 'D_software_server_association')
+        _add_columns(engine, 'D_software_server_association', ['deleted BOOLEAN'])
+        _add_columns(engine, 'D_software', ['deleted BOOLEAN', '"$$name"  VARCHAR(80)'])
+
+        with engine.connect() as connection:
+            connection.execute(text("UPDATE L_parameter SET dump = null, load= null"))
