@@ -60,7 +60,6 @@ class ActionTemplate(db.Model, UUIDistributedEntityMixin):
 
     @orm.reconstructor
     def init_on_load(self):
-        self.parameters = self.parameters or {}
         self.system_kwargs = self.system_kwargs or {}
 
     def __str__(self):
@@ -69,8 +68,9 @@ class ActionTemplate(db.Model, UUIDistributedEntityMixin):
     def to_json(self, split_lines=False):
         data = super().to_json()
         data.update(name=self.name, version=self.version,
-                    action_type=self.action_type.name,
-                    code=self.code.split('\n') if split_lines else self.code)
+                    action_type=self.action_type.name)
+        if self.code is not None:
+            data.update(code=self.code.split('\n') if split_lines else self.code)
         if self.schema is not None:
             data.update(schema=self.schema)
         if self.system_kwargs is not None:
@@ -115,11 +115,10 @@ class ActionTemplate(db.Model, UUIDistributedEntityMixin):
                                                       "max_senders": {"type": "integer"},
                                                       },
                                             "required": ["software_id", "server_id"],
-                                            "output": {"file": {"type": "string",
-                                                                "description": "absolute path file name"}}
+                                            "output": ["file"]
                                             },
                                     id='00000000-0000-0000-000a-000000000001',
-                                    post_process="if cp.success:\n  json_data=json.loads(cp.stdout)\n  vc.set('file', "
+                                    post_process="import json\nif cp.success:\n  json_data=json.loads(cp.stdout)\n  vc.set('file', "
                                                  "json_data.get('file'))")
 
                 session.add(at)
