@@ -36,6 +36,13 @@ class Server(db.Model, UUIDistributedEntityMixin, SoftDeleteMixin):
                                                back_populates="destination", cascade="all, delete-orphan")
     gates: t.List[Gate] = db.relationship("Gate", back_populates="server", cascade="all, delete-orphan")
 
+    log_sources = db.relationship("Log", primaryjoin="Server.id==Log.src_server_id", back_populates="source_server")
+    log_destinations = db.relationship("Log", primaryjoin="Server.id==Log.dst_server_id",
+                                       back_populates="destination_server")
+    files = db.relationship("File", back_populates="source_server")
+    file_server_associations = db.relationship("FileServerAssociation", back_populates="destination_server")
+    software_server_associations = db.relationship("SoftwareServerAssociation", back_populates="server")
+
     # software_list = db.relationship("SoftwareServerAssociation", back_populates="server")
 
     query_class = QueryWithSoftDelete
@@ -145,7 +152,10 @@ class Server(db.Model, UUIDistributedEntityMixin, SoftDeleteMixin):
         ConnectionError:
             if server is unreachable
         """
-        scheme = 'http' if current_app.dm and 'keyfile' not in current_app.dm.config.http_conf else 'https'
+        try:
+            scheme = 'http' if current_app.dm and 'keyfile' not in current_app.dm.config.http_conf else 'https'
+        except:
+            scheme = 'https'
         gate = None
         route = self.route
         if self._me and (route is None or route.cost is None):
@@ -186,7 +196,7 @@ class Server(db.Model, UUIDistributedEntityMixin, SoftDeleteMixin):
 
         """
         if session:
-            query = session.query(cls)
+            query = session.query(cls).filter_by(deleted=0)
         else:
             query = cls.query
         query = query.join(cls.route).filter(Route.cost == 0)
@@ -209,7 +219,7 @@ class Server(db.Model, UUIDistributedEntityMixin, SoftDeleteMixin):
     @classmethod
     def get_not_neighbours(cls, session=None) -> t.List['Server']:
         if session:
-            query = session.query(cls)
+            query = session.query(cls).filter_by(deleted=0)
         else:
             query = cls.query
         return query.outerjoin(cls.route).filter(
@@ -289,7 +299,7 @@ class Server(db.Model, UUIDistributedEntityMixin, SoftDeleteMixin):
         return query.filter_by(_me=True).filter_by(deleted=False).one()
 
     @staticmethod
-    def set_initial(session=None, gates=None):
+    def set_initial(session=None, gates=None) -> Id:
         logger = logging.getLogger('dm.db')
         if session is None:
             session = db.session
@@ -307,8 +317,11 @@ class Server(db.Model, UUIDistributedEntityMixin, SoftDeleteMixin):
                             me=True)
             logger.info(f'Creating Server {server.name} with the following gates: {gates}')
             session.add(server)
+            return server.id
         elif len(server) > 1:
             raise ValueError('Multiple servers found as me.')
+        else:
+            return server[0].id
 
     def ignore_on_lock(self, value: bool):
         if value != self.l_ignore_on_lock:
@@ -330,4 +343,14 @@ class Server(db.Model, UUIDistributedEntityMixin, SoftDeleteMixin):
     def delete(self):
         super().delete()
         for g in self.gates:
-            g.delete()
\ No newline at end of file
+            g.delete()
+        for l in self.log_sources:
+            l.delete()
+        for l in self.log_destinations:
+            l.delete()
+        for ssa in self.software_server_associations:
+            ssa.delete()
+        for fsa in self.file_server_associations:
+            fsa.delete()
+        for f in self.files:
+            f.delete()
