@@ -33,10 +33,7 @@ def status(node, detail=False):
     else:
         for n in node:
             dprint(f"### {n}:") if len(node) > 1 else None
-            if not is_valid_uuid(n):
-                node_id = name2id('api_1_0.serverlist', n)
-            else:
-                node_id = n
+            node_id = normalize2id(n)
             resp = ntwrk.get('root.healthcheck', view_data=view_data, headers={'D-Destination': node_id})
             dprint(resp)
 
@@ -124,7 +121,7 @@ def server_routes(node, refresh=False):
         if refresh:
             resp = ntwrk.post('api_1_0.routes', json={"discover_new_neighbours": True,
                                                       "check_current_neighbours": True}, **kwargs)
-        if resp is None or (resp and resp.ok):
+        else:
             resp = ntwrk.get('api_1_0.routes', view_data={'params': 'human'}, **kwargs)
         dprint(resp)
 
@@ -203,17 +200,18 @@ def orch_load(file):
     try:
         orch = json.load(file)
     except Exception as e:
-        print(e)
+        dprint(e)
     else:
         orch_prompt(orch, parent_prompt='Δ ')
 
 
 def orch_run(orchestration_id, **params):
     if not params['hosts']:
-        exit('No target specified')
-    resp = ntwrk.post('api_1_0.launch_orchestration',
-                      view_data={'orchestration_id': orchestration_id, 'params': 'human'}, json=params)
-    dprint(resp)
+        dprint('No target specified')
+    else:
+        resp = ntwrk.post('api_1_0.launch_orchestration',
+                          view_data={'orchestration_id': orchestration_id, 'params': 'human'}, json=params)
+        dprint(resp)
 
 
 def action_list(ident=None, name=None, version=None, like: str = None, last: int = None):
@@ -281,6 +279,12 @@ def software_add(name, version, file, family=None):
     dprint(resp)
 
 
+def software_delete(software_id):
+    kwargs = {}
+    resp = ntwrk.delete(view='api_1_0.softwareresource', view_data={'software_id': software_id}, **kwargs)
+    dprint(resp)
+
+
 def software_send(dest_server_id, software_id=None, software=None, version=None, file=None, dest_path=None,
                   background=True, force=False):
     kwargs = {}
@@ -344,8 +348,9 @@ def transfer_list(iden=None, status=None, like=None, last=None):
                     filtered_data.append(server)
         else:
             filtered_data = data
-        if last:
-            dprint(filtered_data[:last])
+        assert last is None or last > 0, f"Invalid value '{last}'"
+        if last is not None and last > 0:
+            dprint(filtered_data[-last:])
         else:
             dprint(filtered_data)
     else:
@@ -601,7 +606,7 @@ nested_dict = {
         'create': [{'argument': 'name'},
                    {'argument': 'action_type', 'choices': [at.name for at in ActionType if at.name != 'NATIVE']},
                    {'argument': '--prompt', 'action': "store_true",
-                    'help': 'does not ask for every action parameter one by one'},
+                    'help': 'prompts for every action parameter to be set by user'},
                    action_create],
         'copy': [{'argument': 'action_template_id', 'completer': action_completer},
                  action_copy],
@@ -698,9 +703,9 @@ nested_dict = {
                    "unignore": [{'argument': 'server_ids', 'metavar': 'NODE', 'nargs': '+',
                                  'completer': server_completer},
                                 functools.partial(manager_locker_ignore, False)],
-                   'show': [{'argument': 'node', 'nargs': '+', 'completer': server_completer}, manager_locker_show],
+                   'show': [{'argument': 'node', 'nargs': '+', 'completer': server_name_completer}, manager_locker_show],
                    'unlock': [{'argument': 'scope', 'choices': [s.name for s in Scope]},
-                              {'argument': 'node', 'nargs': '+', 'completer': server_completer},
+                              {'argument': 'node', 'nargs': '+', 'completer': server_name_completer},
                               manager_locker_unlock]
                    },
         "token": [{'argument': 'expires_time', 'nargs': '?', 'metavar': 'MINUTES',
@@ -729,7 +734,7 @@ nested_dict = {
                  orch_load],
         'run': [{'argument': 'orchestration_id', 'completer': orch_completer},
                 {'argument': '--target', 'metavar': 'TARGET=VALUE', 'action': DictAction, 'nargs': "+", 'dest': 'hosts',
-                 'completer': merge_completers([server_completer, granule_completer]),
+                 'completer': merge_completers([server_name_completer, granule_completer]),
                  'help': "Run the orch agains the specified target. If no target specified, hosts will be added to "
                          "'all' target. Example: --target node1 node2 backend=node2,node3 "},
                 {'argument': '--param', 'dest': 'params', 'metavar': 'PARAM:VALUE', 'action': ParamAction, "nargs": "+",
@@ -740,7 +745,7 @@ nested_dict = {
                 {'argument': '--no-wait', 'dest': 'background', 'action': 'store_true'},
                 orch_run],
     },
-    'ping': [{'argument': 'node', 'nargs': '+', 'completer': server_completer}, ping],
+    'ping': [{'argument': 'node', 'nargs': '+', 'completer': server_name_completer}, ping],
     'server': {
         'list': [{'argument': '--detail', 'action': 'store_true'},
                  [{'argument': '--like'},
@@ -751,10 +756,10 @@ nested_dict = {
                  server_list
                  ],
         'delete': [
-            {'argument': 'server_ids', 'metavar': 'NODE', 'nargs': '+', 'completer': server_completer,
+            {'argument': 'server_ids', 'metavar': 'NODE', 'nargs': '+', 'completer': server_name_completer,
              'help': 'Node to be deleted'},
             server_delete],
-        'routes': [{'argument': 'node', 'nargs': '*', 'completer': server_completer},
+        'routes': [{'argument': 'node', 'nargs': '*', 'completer': server_name_completer},
                    {'argument': '--refresh', 'action': 'store_true'},
                    server_routes],
     },
@@ -764,6 +769,8 @@ nested_dict = {
                 {'argument': 'file'},
                 {'argument': '--family', 'completer': software_family_completer},
                 software_add],
+        'delete': [{'argument': 'software_id', 'completer': software_completer},
+                   software_delete],
         'list': [{'argument': '--version', 'action': 'store', 'type': int,
                   'completer': software_ver_completer},
                  {'argument': '--detail', 'action': 'store_true'},
@@ -780,7 +787,7 @@ nested_dict = {
                  {'argument': '--foreground', 'action': 'store_false', 'dest': 'background', 'default': True},
                  {'argument': '--force', 'action': 'store_true'},
                  software_send], },
-    'status': [{'argument': 'node', 'nargs': '*', 'completer': server_completer},
+    'status': [{'argument': 'node', 'nargs': '*', 'completer': server_name_completer},
                {'argument': '--detail', 'action': 'store_true'}, status],
     'sync': {
         'list': [{'argument': '--id', 'dest': 'ident', 'completer': file_completer},
