@@ -130,7 +130,7 @@ def request(method, url, session=None, token_refreshed=False, login=True, **kwar
         kwargs['headers'] = {}
     kwargs['headers'].update({'D-Securizer': 'plain'})
 
-    kwargs['verify'] = False
+    kwargs['verify'] = env.get('SSL_VERIFY')
 
     logger.debug(f"{method.upper()} {url}\n{kwargs}")
 
@@ -218,7 +218,10 @@ def _replace_path_args(path, args):
 
 
 def generate_url(view, view_data, ip=None, port=defaults.DEFAULT_PORT, scheme='https'):
-    path = view_path_map[view]
+    try:
+        path = view_path_map[view]
+    except KeyError:
+        raise RuntimeError(f"'{view}' not set in metadata")
     path = _replace_path_args(path, view_data or {})
     if (env.get('SERVER', ip) or ip) is None:
         raise ValueError('No SERVER specified.')
