@@ -1,7 +1,5 @@
-import asyncio
 import base64
 import logging
-import multiprocessing as mp
 import os
 import queue
 import time
@@ -18,11 +16,13 @@ from watchdog.observers import Observer
 from watchdog.observers.api import ObservedWatch
 
 from dimensigon import defaults
-from dimensigon.domain.entities import File, Server, Log
+from dimensigon.domain.entities import File, Server, Log, FileServerAssociation
 from dimensigon.domain.entities.log import Mode
-from dimensigon.use_cases.base import Process
+from dimensigon.use_cases.cluster import NewEvent, AliveEvent
 from dimensigon.use_cases.helpers import get_root_auth
+from dimensigon.use_cases.mptools import MPQueue, TimerWorker
 from dimensigon.utils import asyncio
+from dimensigon.utils.helpers import remove_root
 from dimensigon.utils.pygtail import Pygtail
 from dimensigon.utils.typos import Id
 from dimensigon.web import network as ntwrk
@@ -30,16 +30,14 @@ from dimensigon.web import network as ntwrk
 if t.TYPE_CHECKING:
     from dimensigon.core import Dimensigon
 
-_logger = logging.getLogger('dm.fileSync')
+_logger = logging.getLogger('dm.FileSync')
 _log_logger = logging.getLogger('dm.logfed')
 
 MAX_LINES = 10000  # max lines readed from a log
-SYNC_INTERVAL = 5
-# period of time process checks for new files added to the database. must be equal or bigger than SYNC_INTERVAL
+# period of time process checks for new files added to the database. must be equal or bigger than defaults.
 FILE_WATCHES_REFRESH_PERIOD = 30
-MAX_ALLOWED_ERRORS = 2
-# retry blacklisted servers after RETRY_BLACKLIST seconds
-RETRY_BLACKLIST = 300
+MAX_ALLOWED_ERRORS = 2  # max allowed errors to consider a node blacklisted
+RETRY_BLACKLIST = 300  # retry blacklisted servers after RETRY_BLACKLIST seconds
 
 
 class _PygtailBuffer(Pygtail):
@@ -63,7 +61,7 @@ class _PygtailBuffer(Pygtail):
 FileWatchId = t.Tuple[Id, str]
 
 
-class EventHandler(PatternMatchingEventHandler):
+class WatchdogEventHandler(PatternMatchingEventHandler):
 
     def __init__(self, fw_id: FileWatchId, fs: 'FileSync', *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
@@ -84,26 +82,25 @@ class BlacklistEntry:
     blacklisted: float = None
 
 
-class FileSync(Process):
-    _logger = _logger
-
-    def __init__(self, dimensigon: 'Dimensigon', sync_interval=SYNC_INTERVAL,
-                 file_watches_refresh_period=FILE_WATCHES_REFRESH_PERIOD, max_allowed_errors=MAX_ALLOWED_ERRORS,
-                 retry_blacklist=RETRY_BLACKLIST):
-        super().__init__(dimensigon.shutdown_event, name=self.__class__.__name__)
+class FileSync(TimerWorker):
+    ###########################
+    # START Class Inheritance #
+    def init_args(self, dimensigon: 'Dimensigon', file_sync_period=defaults.FILE_SYNC_PERIOD,
+                  file_watches_refresh_period=FILE_WATCHES_REFRESH_PERIOD, max_allowed_errors=MAX_ALLOWED_ERRORS,
+                  retry_blacklist=RETRY_BLACKLIST):
         self.dm = dimensigon
 
         # Multiprocessing
-        self.queue = mp.Queue(1000)
+        self.queue = MPQueue()
 
         # Parameters
-        self.sync_interval = sync_interval
+        self.INTERVAL_SECS = file_sync_period
         self.file_watches_refresh_period = file_watches_refresh_period
         self.max_allowed_errors = max_allowed_errors
         self.retry_blacklist = retry_blacklist
 
         # internals
-        self._changed_files: t.Set[Id] = set()
+        self._changed_files: t.Set[Id] = set()  # list of changed files to be sent
         self._changed_servers: t.Dict[Id, t.List[Id]] = dict()
         self._file2watch: t.Dict[Id, ObservedWatch] = {}
         self._last_file_updated = None
@@ -111,10 +108,66 @@ class FileSync(Process):
         self._blacklist_log: t.Dict[t.Tuple[Id, Id], BlacklistEntry] = {}
         self.session = None
         self._server = None
+        self._loop = None
 
         # log variables
         self._mapper: t.Dict[Id, t.List[_PygtailBuffer]] = {}
 
+    def startup(self):
+        self._executor = ThreadPoolExecutor(max_workers=max(os.cpu_count(), 4),
+                                            thread_name_prefix="FileSyncThreadPool")
+        self._observer = Observer()
+        self.session = self._create_session()
+        self._observer.start()
+
+        self._set_initial_modifications()
+        self._loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(self._loop)
+        self.dispatcher.listen([NewEvent, AliveEvent], lambda x: self.add(None, x.args[0]))
+
+    def shutdown(self):
+        self.session.close()
+        self._observer.stop()
+        self._executor.shutdown()
+
+    def main_func(self):
+        # collect new File events
+        while True:
+            item = self.queue.safe_get()
+            if item:
+                self._add(*item)
+            else:
+                break
+        self._set_watchers()
+        self._sync_files()
+
+        # send log data
+        self._send_new_data()
+
+    # END Class Inheritance #
+    #########################
+
+    ############################
+    # INIT Interface functions #
+    def add(self, file: t.Union[File, Id] = None, server: t.Union[Server, Id] = None):
+        if isinstance(file, File):
+            file_id = file.id
+        else:
+            file_id = file
+        if isinstance(server, Server):
+            server_id = server.id
+        else:
+            server_id = server
+        try:
+            self.queue.safe_put((file_id, server_id), timeout=2)
+        except queue.Full:
+            self.logger.warning("Queue is full. Try increasing its size")
+
+    # END Interface functions  #
+    ############################
+
+    ##############################
+    # INNER methods & attributes #
     def _create_session(self):
         self.Session = sessionmaker(bind=self.dm.engine)
         return self.Session()
@@ -140,9 +193,18 @@ class FileSync(Process):
         return self.file_query.filter_by(id=file_id).one_or_none() if self.session else None
         # return self.file_query.filter_by(id=file_id).one_or_none()
 
-    def _add(self, file_id: Id, server_id: Id = None):
+    def _add(self, file_id: Id = None, server_id: Id = None):
         if server_id:
-            if file_id not in self._changed_files:
+            if file_id is None:
+                # new server alive, send all files
+                for fsa in self.session.query(FileServerAssociation).filter_by(dst_server_id=server_id, deleted=0).join(
+                        File).filter_by(src_server_id=self.server.id).all():
+                    if not (getattr(fsa.file, 'deleted', True) or fsa.destination_server.deleted):
+                        mtime = os.stat(fsa.target).st_mtime_ns
+                        if fsa.l_mtime != mtime:
+                            self._add(fsa.file.id, fsa.destination_server.id)
+            elif file_id not in self._changed_files:
+                # send data to a specific server
                 if file_id not in self._changed_servers:
                     self._changed_servers[file_id] = [server_id]
                 else:
@@ -165,7 +227,7 @@ class FileSync(Process):
         try:
             content = await self._loop.run_in_executor(self._executor, self._read_file, file.target)
         except Exception as e:
-            _logger.exception(f"Unable to get content from file {file.target}.")
+            self.logger.exception(f"Unable to get content from file {file.target}.")
             return
 
         if servers:
@@ -184,16 +246,16 @@ class FileSync(Process):
                                       auth=auth) for fsa in fsas if fsa.destination_server.id in alive]
             skipped = [fsa.destination_server.name for fsa in fsas if fsa.destination_server.id not in alive]
             if skipped:
-                _logger.debug(
+                self.logger.debug(
                     f"Following servers are skipped because we do not see them alive: {', '.join(skipped)}")
             if tasks:
-                _logger.debug(
+                self.logger.debug(
                     f"Syncing file {file} with the following servers: {', '.join([fsa.destination_server.name for fsa in fsas if fsa.destination_server.id in alive])}.")
 
                 resp = await asyncio.gather(*tasks)
                 for resp, fsa in zip(resp, fsas):
                     if not resp.ok:
-                        _logger.warning(
+                        self.logger.warning(
                             f"Unable to send file {file.target} to {fsa.destination_server}. Reason: {resp}")
                         if (file.id, fsa.destination_server.id) not in self._blacklist:
                             bl = BlacklistEntry()
@@ -202,7 +264,7 @@ class FileSync(Process):
                             bl = self._blacklist.get((file.id, fsa.destination_server.id))
                         bl.retries += 1
                         if bl.retries >= self.max_allowed_errors:
-                            _logger.debug(f"Adding server {fsa.destination_server} to the blacklist.")
+                            self.logger.debug(f"Adding server {fsa.destination_server} to the blacklist.")
                             bl.blacklisted = time.time()
                     else:
                         if (file.id, fsa.destination_server.id) in self._blacklist:
@@ -214,7 +276,7 @@ class FileSync(Process):
                     self.session.rollback()
 
     def _sync_files(self):
-        tasks = []
+        coros = []
         for file_id in self._changed_files:
             f = self.get_file(file_id)
             if f:
@@ -223,8 +285,8 @@ class FileSync(Process):
                 except FileNotFoundError:
                     pass
                 else:
-                    tasks.append(self._send_file(f))
-        if tasks:
+                    coros.append(self._send_file(f))
+        if coros:
             try:
                 self.session.commit()
             except:
@@ -238,20 +300,20 @@ class FileSync(Process):
                 # if server_id in getattr(getattr(self.app, 'cluster_manager', None), 'cluster', [server_id]):
                 if bl.retries < self.max_allowed_errors or time.time() - bl.blacklisted > self.retry_blacklist:
                     if file_id not in self._changed_files:
-                        tasks.append(self._send_file(file, [server_id]))
+                        coros.append(self._send_file(file, [server_id]))
             else:
                 self._blacklist.pop((file_id, server_id), None)
 
         for file_id, server_ids in self._changed_servers.items():
             file = self.get_file(file_id)
             if file:
-                tasks.append(self._send_file(file, server_ids))
+                coros.append(self._send_file(file, server_ids))
 
-        if tasks:
+        if coros:
             try:
-                self._loop.run_until_complete(asyncio.gather(*tasks, return_exceptions=False))
+                self._loop.run_until_complete(asyncio.gather(*coros, return_exceptions=False))
             except Exception:
-                _logger.exception("Error while trying to send data.")
+                self.logger.exception("Error while trying to send data.")
         self._changed_files.clear()
         self._changed_servers.clear()
 
@@ -260,9 +322,9 @@ class FileSync(Process):
             target = file_id.target
             file_id = file_id.id
         assert target is not None
-        eh = EventHandler(file_id, self, patterns=[target])
+        weh = WatchdogEventHandler(file_id, self, patterns=[target])
         try:
-            watch = self._observer.schedule(eh, os.path.dirname(target), recursive=False)
+            watch = self._observer.schedule(weh, os.path.dirname(target), recursive=False)
         except FileNotFoundError:
             pass
         else:
@@ -294,65 +356,21 @@ class FileSync(Process):
             file_watches_to_add = files_from_db - files_already_watching
 
             if file_watches_to_remove:
-                _logger.debug(f"Unscheduling the following files: {file_watches_to_remove}")
+                self.logger.debug(f"Unscheduling the following files: {file_watches_to_remove}")
                 for file_id in file_watches_to_remove:
                     self._observer.unschedule(self._file2watch[file_id])
                     self._file2watch.pop(file_id)
 
             if file_watches_to_add:
-                _logger.debug(f"Scheduling the following files: {file_watches_to_add}")
+                self.logger.debug(f"Scheduling the following files: {file_watches_to_add}")
                 for file_id in file_watches_to_add:
                     self._schedule_file(file_id, id2target[file_id])
                     # add for sending file for first time
                     self._add(file_id, None)
 
-    def _main(self):
-        self._executor = ThreadPoolExecutor(max_workers=max(os.cpu_count(), 4),
-                                            thread_name_prefix="FileSyncThreadPool")
-        self._loop = asyncio.new_event_loop()
-        self._loop.set_default_executor(self._executor)
-        asyncio.set_event_loop(self._loop)
-        self._observer = Observer()
-        self.session = self._create_session()
-        self._observer.start()
 
-        self._set_initial_modifications()
-        start = time.time()
-        while not self._stop.is_set():
-            try:
-                item = self.queue.get(block=True, timeout=0.2)
-            except queue.Empty:
-                pass
-            else:
-                self._add(*item)
-            if time.time() - start > self.sync_interval:
-                start = time.time()
-                self._set_watchers()
-                self._sync_files()
-                self._send_new_data()
 
-    def _shutdown(self):
-        # self.queue.close()
-        # self.queue.join_thread()
-        self._observer.stop()
-        self.session.close()
-        self._loop.stop()
-        self._loop.close()
-        self._executor.shutdown()
 
-    def add(self, file: t.Union[File, Id], server: t.Union[Server, Id] = None):
-        if isinstance(file, File):
-            file_id = file.id
-        else:
-            file_id = file
-        if isinstance(server, Server):
-            server_id = server.id
-        else:
-            server_id = server
-        try:
-            self.queue.put((file_id, server_id), timeout=2)
-        except queue.Full:
-            _logger.warning("Queue is full. Try increasing its size")
 
     @property
     def my_logs(self):
@@ -377,7 +395,10 @@ class FileSync(Process):
             if len(pytail_list) == 0:
                 filename = '.' + os.path.basename(log.target) + '.offset'
                 path = os.path.dirname(log.target)
-                offset_file = self.dm.config.path(defaults.OFFSET_DIR, path, filename)
+                offset_file = self.dm.config.path(defaults.OFFSET_DIR, remove_root(path), filename)
+                if not os.path.exists(offset_file):
+                    _log_logger.debug(f"creating offset file {offset_file}")
+                    os.makedirs(os.path.dirname(offset_file), exist_ok=True)
                 pytail_list.append(
                     _PygtailBuffer(file=log.target, offset_mode='manual', offset_file=offset_file))
         else:
@@ -440,25 +461,26 @@ class FileSync(Process):
                     tasks[task] = (pytail, log)
                     _log_logger.debug(f"Task sending data from '{pytail.file}' to '{log.destination_server}' prepared")
 
-        with self.dm.flask_app.app_context():
-            responses = self._loop.run_until_complete(asyncio.gather(*list(tasks.keys())))
+        if tasks:
+            with self.dm.flask_app.app_context():
+                responses = asyncio.run(asyncio.gather(*list(tasks.keys())))
 
-        for task, resp in zip(tasks.keys(), responses):
-            pytail, log = tasks[task]
-            if resp.ok:
-                pytail.update_offset_file()
-                _log_logger.debug(f"Updated offset from '{pytail.file}'")
-                if log.id not in self._blacklist:
-                    self._blacklist_log.pop(log.id, None)
-            else:
-                _log_logger.error(
-                    f"Unable to send log information from '{pytail.file}' to '{log.destination_server}'. Error: {resp}")
-                if log.id not in self._blacklist:
-                    bl = BlacklistEntry()
-                    self._blacklist_log[log.id] = bl
+            for task, resp in zip(tasks.keys(), responses):
+                pytail, log = tasks[task]
+                if resp.ok:
+                    pytail.update_offset_file()
+                    _log_logger.debug(f"Updated offset from '{pytail.file}'")
+                    if log.id not in self._blacklist:
+                        self._blacklist_log.pop(log.id, None)
                 else:
-                    bl = self._blacklist_log.get(log.id)
-                bl.retries += 1
-                if bl.retries >= self.max_allowed_errors:
-                    _log_logger.debug(f"Adding server {log.destination_server.id} to the blacklist.")
-                    bl.blacklisted = time.time()
+                    _log_logger.error(
+                        f"Unable to send log information from '{pytail.file}' to '{log.destination_server}'. Error: {resp}")
+                    if log.id not in self._blacklist:
+                        bl = BlacklistEntry()
+                        self._blacklist_log[log.id] = bl
+                    else:
+                        bl = self._blacklist_log.get(log.id)
+                    bl.retries += 1
+                    if bl.retries >= self.max_allowed_errors:
+                        _log_logger.debug(f"Adding server {log.destination_server.id} to the blacklist.")
+                        bl.blacklisted = time.time()
