@@ -6,6 +6,7 @@ import os
 import re
 import sqlite3
 import sys
+import tempfile
 import time
 import typing as t
 from abc import ABC, abstractmethod
@@ -81,7 +82,7 @@ class IOperationEncapsulation(ABC):
         return
 
     @abstractmethod
-    def execute(self, params: Kwargs, timeout=None, context: Context = None) -> CompletedProcess:
+    def _execute(self, params: Kwargs, timeout=None, context: Context = None) -> CompletedProcess:
         """
         StepExecution process
         Parameters
@@ -97,6 +98,28 @@ class IOperationEncapsulation(ABC):
             dataclass containing all the information from the result execution
         """
 
+    def execute(self, params: Kwargs, timeout=None, context: Context = None) -> CompletedProcess:
+        """
+        StepExecution wrapper
+        Parameters
+        ----------
+        properties:
+            properties passed to execute implementation
+        env:
+            environment variables
+
+        Returns
+        -------
+        StepExecution:
+            dataclass containing all the information from the result execution
+        """
+        start = get_now()
+        try:
+            return self._execute(params, timeout=timeout, context=context)
+        except Exception as e:
+            return CompletedProcess(success=False, stderr=f"Error creating execution: {str(e)}", start_time=start,
+                                    end_time=get_now())
+
     def rpl_params(self, params: Kwargs, env: Kwargs):
         template = jinja2.Template(self.code)
         return template.render(input=params, env=env)
@@ -110,7 +133,7 @@ class IOperationEncapsulation(ABC):
                     if match:
                         res.append(True)
                         if context:
-                            for k, v in match.groupdict():
+                            for k, v in match.groupdict().items():
                                 context.set(k, v)
                     else:
                         res.append(False)
@@ -120,7 +143,7 @@ class IOperationEncapsulation(ABC):
                     if match:
                         res.append(True)
                         if context:
-                            for k, v in match.groupdict():
+                            for k, v in match.groupdict().items():
                                 context.set(k, v)
                     else:
                         res.append(False)
@@ -165,7 +188,7 @@ class IOperationEncapsulation(ABC):
 
 class RequestOperation(IOperationEncapsulation):
 
-    def execute(self, params: Kwargs, timeout=None, context: Context = None) -> CompletedProcess:
+    def _execute(self, params: Kwargs, timeout=None, context: Context = None) -> CompletedProcess:
         kwargs = json.loads(self.rpl_params(params, context.env))
         kwargs.update(self.system_kwargs)
         cp = CompletedProcess()
@@ -200,13 +223,13 @@ class RequestOperation(IOperationEncapsulation):
 
 class NativeOperation(IOperationEncapsulation):
 
-    def execute(self, params: Kwargs, timeout=None, context: Context = None):
+    def _execute(self, params: Kwargs, timeout=None, context: Context = None):
         pass
 
 
 class NativeSoftwareSendOperation(IOperationEncapsulation):
 
-    def execute(self, params: Kwargs, timeout=None, context: Context = None) -> CompletedProcess:
+    def _execute(self, params: Kwargs, timeout=None, context: Context = None) -> CompletedProcess:
         params_dict = dict(params)
         cp = CompletedProcess()
         cp.set_start_time()
@@ -287,7 +310,7 @@ class NativeSoftwareSendOperation(IOperationEncapsulation):
 
 class NativeWaitOperation(IOperationEncapsulation):
 
-    def execute(self, params: Kwargs, timeout=None, context: Context = None):
+    def _execute(self, params: Kwargs, timeout=None, context: Context = None):
         start = time.time()
         found = []
         cp = CompletedProcess()
@@ -337,7 +360,7 @@ class NativeWaitOperation(IOperationEncapsulation):
 
 class NativeDmRunningOperation(IOperationEncapsulation):
 
-    def execute(self, params: Kwargs, timeout=None, context: Context = None):
+    def _execute(self, params: Kwargs, timeout=None, context: Context = None):
         start = time.time()
         running = []
         cp = CompletedProcess()
@@ -382,7 +405,7 @@ class NativeDmRunningOperation(IOperationEncapsulation):
 
 class NativeDeleteOperation(IOperationEncapsulation):
 
-    def execute(self, params: Kwargs, timeout=None, context: Context = None):
+    def _execute(self, params: Kwargs, timeout=None, context: Context = None):
         cp = CompletedProcess()
         cp.set_start_time()
         try:
@@ -494,27 +517,38 @@ class ShellOperation(IOperationEncapsulation):
     #     env.update(**os.environ)
     #     return env
 
-    def execute(self, params: Kwargs, timeout=None, context: Context = None) -> CompletedProcess:
+    def _execute(self, params: Kwargs, timeout=None, context: Context = None) -> CompletedProcess:
         tokens = self.rpl_params(params, context.env)
 
         system_kwargs = self.system_kwargs.copy()
 
-        timeout = system_kwargs.pop('timeout', 300)
+        shebang = system_kwargs.pop('shebang', '/bin/bash')
+        user = system_kwargs.pop('run_as', None)
+        timeout = system_kwargs.pop('timeout', None)
 
         cp = CompletedProcess()
         cp.set_start_time()
-
+        tmp = tempfile.NamedTemporaryFile('w', delete=False)
+        tmp.write(f"#!{shebang}\n")
+        tmp.write(tokens)
+        tmp.close()
+        os.chmod(tmp.name, 0o755)
         r = None
+
+        if user:
+            cmd = f"sudo -niu {user} {tmp.name}"
+        else:
+            cmd = tmp.name
         try:
-            r = subprocess.run(tokens, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE,
-                               **system_kwargs, timeout=timeout, env=os.environ)
+            r = subprocess.run(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, timeout=timeout, shell=True)
             cp.stdout = r.stdout.decode() if isinstance(r.stdout, bytes) else r.stdout
             cp.stderr = r.stderr.decode() if isinstance(r.stderr, bytes) else r.stderr
             cp.rc = r.returncode
-        except (subprocess.TimeoutExpired, ValueError) as e:
-            cp.stderr = f"{e.__class__.__name__}{e.args}"
+        except subprocess.TimeoutExpired as e:
+            cp.stderr = str(e)
             cp.success = False
         finally:
+            os.remove(tmp.name)
             cp.set_end_time()
 
         self.evaluate_result(cp, context)
