@@ -2,6 +2,8 @@ from .action_template import ActionTemplateList, ActionTemplateResource
 from .execution import OrchExecutionList, OrchExecutionResource, OrchestrationExecutionRelationship, StepExecutionList, \
     StepExecutionResource, OrchExecStepExecRelationship
 from .granule import GranuleList
+from .file import FileList, FileResource
+from .file_server_association import FileServerAssociationList
 from .log import LogList, LogResource
 from .orchestration import OrchestrationList, OrchestrationResource
 from .server import ServerList, ServerResource
