@@ -2,6 +2,7 @@ import logging
 import threading
 from datetime import datetime
 
+from sqlalchemy.exc import OperationalError
 from flask import request, current_app, g, jsonify
 from flask_jwt_extended import jwt_required, get_jwt_identity
 
@@ -11,9 +12,10 @@ from dimensigon.domain.entities.locker import Scope, State, Locker
 from dimensigon.web import db, errors
 from dimensigon.web.api_1_0 import api_bp
 from dimensigon.web.decorators import securizer, forward_or_dispatch, validate_schema
+from dimensigon.web.helpers import transaction
 from dimensigon.web.json_schemas import locker_prevent_post, locker_unlock_lock_post
 
-logger = logging.getLogger('dimensigon.lock')
+logger = logging.getLogger('dm.lock')
 
 @api_bp.route('/locker', methods=['GET'])
 @forward_or_dispatch()
@@ -28,11 +30,15 @@ def locker():
 
 def revert_preventing(app, scope, applicant):
     with app.app_context():
-        l = Locker.query.with_for_update().get(scope)
-        if l.state == State.PREVENTING and l.applicant == applicant:
-            l.state = State.UNLOCKED
-            l.applicant = None
-        db.session.commit()
+        try:
+            l = Locker.query.with_for_update().get(scope)
+            if l.state == State.PREVENTING and l.applicant == applicant:
+                l.state = State.UNLOCKED
+                l.applicant = None
+
+            db.session.commit()
+        except OperationalError as e:
+            db.session.rollback()
 
 
 @api_bp.route('/locker/prevent', methods=['POST'])
@@ -42,7 +48,7 @@ def revert_preventing(app, scope, applicant):
 @validate_schema(POST=locker_prevent_post)
 def locker_prevent():
     json_data = request.get_json()
-    l: Locker = Locker.query.with_for_update().get(Scope[json_data['scope']])
+    l: Locker = Locker.query.get(Scope[json_data['scope']])
     logger.debug(f"PreventLock requested on {json_data.get('scope')} from {g.source}")
 
     # when orchestration scope check if applicant is the same as the current
@@ -64,12 +70,12 @@ def locker_prevent():
                 catalog_ver = Catalog.max_catalog()
                 if datemark < catalog_ver:
                     raise errors.ObsoleteCatalog(catalog_ver, datemark)
-            l.state = State.PREVENTING
-            l.applicant = json_data.get('applicant')
+            with transaction():
+                l.state = State.PREVENTING
+                l.applicant = json_data.get('applicant')
             th = threading.Timer(defaults.TIMEOUT_PREVENTING_LOCK, revert_preventing,
                                  (current_app._get_current_object(), l.scope, l.applicant))
             th.daemon = True
-            db.session.commit()
             th.start()
             return {json_data['scope']: 'PREVENTING'}, 200
         else:
@@ -85,7 +91,7 @@ def locker_prevent():
 @validate_schema(POST=locker_unlock_lock_post)
 def locker_lock():
     json_data = request.get_json()
-    l: Locker = Locker.query.with_for_update().get(Scope[json_data['scope']])
+    l: Locker = Locker.query.get(Scope[json_data['scope']])
     logger.debug(f"Lock requested on {json_data.get('scope')} from {g.source}")
 
     if Scope[json_data['scope']] == Scope.ORCHESTRATION \
@@ -95,8 +101,8 @@ def locker_lock():
 
     if l.state == State.PREVENTING:
         if l.applicant == json_data['applicant']:
-            l.state = State.LOCKED
-            db.session.commit()
+            with transaction():
+                l.state = State.LOCKED
             logger.debug(f"Lock from {g.source} on {l.scope.name} acquired")
             return {json_data['scope']: 'LOCKED'}, 200
         else:
@@ -112,16 +118,16 @@ def locker_lock():
 @validate_schema(POST=locker_unlock_lock_post)
 def locker_unlock():
     json_data = request.get_json()
-    l: Locker = Locker.query.with_for_update().get(Scope[json_data['scope']])
+    l: Locker = Locker.query.get(Scope[json_data['scope']])
     logger.debug(f"Unlock requested on {json_data.get('scope')} from {g.source}")
 
     if 'force' in json_data and json_data['force']:
         if get_jwt_identity() != '00000000-0000-0000-0000-000000000001':
             raise errors.UserForbiddenError()
         else:
-            l.state = State.UNLOCKED
-            l.applicant = None
-            db.session.commit()
+            with transaction():
+                l.state = State.UNLOCKED
+                l.applicant = None
             return {json_data['scope']: 'UNLOCKED'}, 200
 
     if Scope[json_data['scope']] == Scope.ORCHESTRATION and l.state == State.UNLOCKED:
@@ -129,9 +135,9 @@ def locker_unlock():
 
     if l.state == State.PREVENTING or l.state == State.LOCKED:
         if l.applicant == json_data['applicant']:
-            l.state = State.UNLOCKED
-            l.applicant = None
-            db.session.commit()
+            with transaction():
+                l.state = State.UNLOCKED
+                l.applicant = None
             logger.debug(f"Lock on {l.scope.name} released")
             return {json_data['scope']: 'UNLOCKED'}, 200
         else:
