@@ -22,11 +22,10 @@ login_post = {
 healthcheck_post = {
     "type": "object",
     "properties": {
-        "exclude": {"type": "array",
-                    "items": Id},
+        "me": Id,
         "heartbeat": {"type": "string"},
     },
-    "required": ["exclude", "heartbeat"],
+    "required": ["me", "heartbeat"],
     "additionalProperties": False
 }
 
@@ -115,16 +114,6 @@ software_post = {
     "additionalProperties": False
 }
 
-software_patch = {
-    "type": "object",
-    "properties": {
-        "server_id": Id,
-        "path": {"type": "string"},
-    },
-    "required": ["server_id", "path"],
-    "additionalProperties": False
-}
-
 software_servers_put = {
     "type": "array",
     "items": {
@@ -138,6 +127,14 @@ software_servers_put = {
     "additionalProperties": False
 }
 
+software_servers_patch = software_servers_put
+
+software_servers_delete = {
+    "type": "array",
+    "items": Id,
+    "additionalProperties": False
+}
+
 schema = {"type": "object",
           "properties": {
               "input": {"type": "object"},
@@ -379,9 +376,8 @@ routes_post = {
     "properties": {
         "discover_new_neighbours": {"type": "boolean"},
         "check_current_neighbours": {"type": "boolean"},
-        "retries": {"type": "integer", "minimum": 1},
-        "timeout": {"type": "number", "minimum": 0},
-        "background": {"type": "boolean"}
+        "max_num_discovery": {"type": ["integer", "null"],
+                              "minimum": 1}
     },
     "additionalProperties": False
 }
